##  Technology Standards Management Capabilities
The following table provides an overview of features related to managing technology standards.
Feature | Capabilities for Technology Standards Management
---|---
[ServiceNow Integration](https://help.sap.com/docs/leanix/ea/servicenow-integration?locale=en-US&state=PRODUCTION&version=CLOUD "Fundamentals of the SAP LeanIX integration with ServiceNow \(CMDB\).") |
  * Automated discovery of IT components
  * Real-time mapping and up-to-date visualization of the relationship between applications and underlying technology, providing enhanced risk visibility


[Self-Built Software Discovery](https://help.sap.com/docs/leanix/ea/self-built-software-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX Technology Risk and Compliance enables you to automate the discovery of your self-built software by integrating this process into your developer toolchain.") |
  * Microservice discovery using a manifest file
  * Self-Built Software Discovery API for SBOM ingestion
  * Auto-detecting programming frameworks and database technologies derived from SBOM data and creating IT components of type software linked to the microservice


[SBOM Explorer](https://help.sap.com/docs/leanix/ea/sbom-explorer?locale=en-US&state=PRODUCTION&version=CLOUD "The SBOM explorer helps you understand your open-source libraries' usage, manage them, track them during cybersecurity incidents, and quickly take action to address risks and compliance issues.") |
  * During cybersecurity incidents like [log4j![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.ncsc.gov.uk%2Finformation%2Flog4j-vulnerability-what-everyone-needs-to-know "https://www.ncsc.gov.uk/information/log4j-vulnerability-what-everyone-needs-to-know") or [SolarWinds![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.gao.gov%2Fproducts%2Fgao-22-104746 "https://www.gao.gov/products/gao-22-104746"), quickly identify the affected blast radius, such as microservices, applications, business capabilities, teams, etc., to effectively address the issues.
  * Analyze how software components are used in your technology portfolio to understand the risks associated with self-built software in the business context to drive impactful IT transformation.


[Meta Model Extension](https://help.sap.com/docs/leanix/ea/workspace-setup-for-self-built-software-discovery?locale=en-US&state=PRODUCTION&version=CLOUD#loio275e3cdd7a44101488219c38543d47a2__meta_model_extension) | Extension of the meta model with a microservice fact sheet subtype, linking microservices to business applications and teams. It also adds fields for Git repository details and SBOM linkage, providing comprehensive insights into each microservice’s context and dependencies.


